@@ -73,7 +73,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
     SfxBindings&		rBindings	= pTabViewShell->GetViewFrame()->GetBindings();
     ScModule*			pScMod		= SC_MOD();
     const SfxItemSet*	pReqArgs	= rReq.GetArgs();
-    USHORT				nSlot		= rReq.GetSlot();
+    sal_uInt16				nSlot		= rReq.GetSlot();
 
     if (nSlot != SID_CURRENTCELL)		// der kommt beim MouseButtonUp
         pTabViewShell->HideListBox();	// Autofilter-DropDown-Listbox
@@ -85,10 +85,10 @@ void ScCellShell::Execute( SfxRequest& rReq )
             //	beim Oeffnen eines Referenz-Dialogs darf die SubShell nicht umgeschaltet werden
             //	(beim Schliessen des Dialogs wird StopEditShell gerufen)
             case SID_OPENDLG_FUNCTION:
-                    //	#53318# inplace macht die EditShell Aerger...
+                    //	inplace macht die EditShell Aerger...
                     //!	kann nicht immer umgeschaltet werden ????
                     if (!pTabViewShell->GetViewFrame()->GetFrame().IsInPlace())
-                        pTabViewShell->SetDontSwitch(TRUE);			// EditShell nicht abschalten
+                        pTabViewShell->SetDontSwitch(sal_True);			// EditShell nicht abschalten
                     // kein break
 
             case FID_CELL_FORMAT:
@@ -101,7 +101,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     pScMod->InputEnterHandler();
                     pTabViewShell->UpdateInputHandler();
 
-                    pTabViewShell->SetDontSwitch(FALSE);
+                    pTabViewShell->SetDontSwitch(false);
 
                     break;
 
@@ -125,7 +125,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                  * 1: ER	Click erweitert Selektion
                  * 2: ERG	Click definiert weitere Selektion
                  */
-                UINT16 nMode = ((const SfxUInt16Item&)pReqArgs->Get( nSlot )).GetValue();
+                sal_uInt16 nMode = ((const SfxUInt16Item&)pReqArgs->Get( nSlot )).GetValue();
 
                 switch ( nMode )
                 {
@@ -143,7 +143,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 //	no arguments (also executed by double click on the status bar controller):
                 //	advance to next selection mode
 
-                USHORT nModifiers = pTabViewShell->GetLockedModifiers();
+                sal_uInt16 nModifiers = pTabViewShell->GetLockedModifiers();
                 switch ( nModifiers )
                 {
                     case KEY_SHIFT:	nModifiers = KEY_MOD1;	break;		// EXT -> ADD
@@ -197,7 +197,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     ScInputHandler* pHdl = SC_MOD()->GetInputHdl( pTabViewShell );
                     if ( !pHdl || !pHdl->IsInEnterHandler() )
                     {
-                        //	#101061# UpdateInputHandler is needed after the cell content
+                        //	UpdateInputHandler is needed after the cell content
                         //	has changed, but if called from EnterHandler, UpdateInputHandler
                         //	will be called later when moving the cursor.
 
@@ -247,7 +247,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     }
                     else if ( aString.Len() > 0 && ( aString.GetChar(0) == '=' || aString.GetChar(0) == '+' || aString.GetChar(0) == '-' ) )
                     {
-                        pTabViewShell->EnterData( aCursorPos.Col(), aCursorPos.Row(), aCursorPos.Tab(), aString, TRUE, pData );
+                        pTabViewShell->EnterData( aCursorPos.Col(), aCursorPos.Row(), aCursorPos.Tab(), aString, sal_True, pData );
                     }
                     else
                     {
@@ -302,22 +302,22 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
         case SID_OPENDLG_FUNCTION:
             {
-                USHORT nId = SID_OPENDLG_FUNCTION;
+                sal_uInt16 nId = SID_OPENDLG_FUNCTION;
                 SfxViewFrame* pViewFrm = pTabViewShell->GetViewFrame();
                 SfxChildWindow* pWnd = pViewFrm->GetChildWindow( nId );
 
-                pScMod->SetRefDialog( nId, pWnd ? FALSE : TRUE );
+                pScMod->SetRefDialog( nId, pWnd ? false : sal_True );
                 rReq.Ignore();
             }
             break;
 
         case SID_OPENDLG_CONSOLIDATE:
             {
-                USHORT			nId  = ScConsolidateDlgWrapper::GetChildWindowId();
+                sal_uInt16			nId  = ScConsolidateDlgWrapper::GetChildWindowId();
                 SfxViewFrame* pViewFrm = pTabViewShell->GetViewFrame();
                 SfxChildWindow* pWnd = pViewFrm->GetChildWindow( nId );
 
-                pScMod->SetRefDialog( nId, pWnd ? FALSE : TRUE );
+                pScMod->SetRefDialog( nId, pWnd ? false : sal_True );
             }
             break;
 
@@ -339,10 +339,10 @@ void ScCellShell::Execute( SfxRequest& rReq )
                                                         ATTR_PATTERN_END );
 
                     const SfxPoolItem*	pAttr = NULL;
-                    USHORT				nWhich = 0;
+                    sal_uInt16				nWhich = 0;
 
                     for ( nWhich=ATTR_PATTERN_START; nWhich<=ATTR_PATTERN_END; nWhich++ )
-                        if ( pReqArgs->GetItemState( nWhich, TRUE, &pAttr ) == SFX_ITEM_SET )
+                        if ( pReqArgs->GetItemState( nWhich, sal_True, &pAttr ) == SFX_ITEM_SET )
                             pNewSet->Put( *pAttr );
 
                     pTabViewShell->ApplyAttributes( pNewSet, pEmptySet );
@@ -365,31 +365,31 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
         case SID_OPENDLG_SOLVE:
             {
-                USHORT			nId  = ScSolverDlgWrapper::GetChildWindowId();
+                sal_uInt16			nId  = ScSolverDlgWrapper::GetChildWindowId();
                 SfxViewFrame* pViewFrm = pTabViewShell->GetViewFrame();
                 SfxChildWindow* pWnd = pViewFrm->GetChildWindow( nId );
 
-                pScMod->SetRefDialog( nId, pWnd ? FALSE : TRUE );
+                pScMod->SetRefDialog( nId, pWnd ? false : sal_True );
             }
             break;
 
         case SID_OPENDLG_OPTSOLVER:
             {
-                USHORT nId = ScOptSolverDlgWrapper::GetChildWindowId();
+                sal_uInt16 nId = ScOptSolverDlgWrapper::GetChildWindowId();
                 SfxViewFrame* pViewFrm = pTabViewShell->GetViewFrame();
                 SfxChildWindow* pWnd = pViewFrm->GetChildWindow( nId );
 
-                pScMod->SetRefDialog( nId, pWnd ? FALSE : TRUE );
+                pScMod->SetRefDialog( nId, pWnd ? false : sal_True );
             }
             break;
 
         case SID_OPENDLG_TABOP:
             {
-                USHORT			nId  = ScTabOpDlgWrapper::GetChildWindowId();
+                sal_uInt16			nId  = ScTabOpDlgWrapper::GetChildWindowId();
                 SfxViewFrame* pViewFrm = pTabViewShell->GetViewFrame();
                 SfxChildWindow* pWnd = pViewFrm->GetChildWindow( nId );
 
-                pScMod->SetRefDialog( nId, pWnd ? FALSE : TRUE );
+                pScMod->SetRefDialog( nId, pWnd ? false : sal_True );
             }
             break;
 
@@ -431,7 +431,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                         String aName;
                         String aComment;
                         Color  aColor;
-                        USHORT nFlags;
+                        sal_uInt16 nFlags;
 
                         pDoc->GetName( nTab, aBaseName );
                         aBaseName += '_';
@@ -440,13 +440,13 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
                         //	vorneweg testen, ob der Prefix als gueltig erkannt wird
                         //	wenn nicht, nur doppelte vermeiden
-                        BOOL bPrefix = pDoc->ValidTabName( aBaseName );
+                        sal_Bool bPrefix = pDoc->ValidTabName( aBaseName );
                         DBG_ASSERT(bPrefix, "ungueltiger Tabellenname");
 
                         while ( pDoc->IsScenario(nTab+i) )
                             i++;
 
-                        BOOL bValid;
+                        sal_Bool bValid;
                         SCTAB nDummy;
                         do
                         {
@@ -465,9 +465,9 @@ void ScCellShell::Execute( SfxRequest& rReq )
                             String aArgName;
                             String aArgComment;
                             const SfxPoolItem* pItem;
-                            if ( pReqArgs->GetItemState( SID_SCENARIOS, TRUE, &pItem ) == SFX_ITEM_SET )
+                            if ( pReqArgs->GetItemState( SID_SCENARIOS, sal_True, &pItem ) == SFX_ITEM_SET )
                                 aArgName = ((const SfxStringItem*)pItem)->GetValue();
-                            if ( pReqArgs->GetItemState( SID_NEW_TABLENAME, TRUE, &pItem ) == SFX_ITEM_SET )
+                            if ( pReqArgs->GetItemState( SID_NEW_TABLENAME, sal_True, &pItem ) == SFX_ITEM_SET )
                                 aArgComment = ((const SfxStringItem*)pItem)->GetValue();
 
                             aColor = Color( COL_LIGHTGRAY );		// Default
@@ -479,11 +479,11 @@ void ScCellShell::Execute( SfxRequest& rReq )
                         }
                         else
                         {
-                            BOOL bSheetProtected = pDoc->IsTabProtected(nTab);
+                            sal_Bool bSheetProtected = pDoc->IsTabProtected(nTab);
                             ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                             DBG_ASSERT(pFact, "ScAbstractFactory create fail!");
 
-                            AbstractScNewScenarioDlg* pNewDlg = pFact->CreateScNewScenarioDlg( pTabViewShell->GetDialogParent(), aName, RID_SCDLG_NEWSCENARIO, FALSE,bSheetProtected);
+                            AbstractScNewScenarioDlg* pNewDlg = pFact->CreateScNewScenarioDlg( pTabViewShell->GetDialogParent(), aName, RID_SCDLG_NEWSCENARIO, false,bSheetProtected);
                             DBG_ASSERT(pNewDlg, "Dialog create fail!");
                             if ( pNewDlg->Execute() == RET_OK )
                             {
@@ -522,8 +522,8 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     const SfxUInt16Item&  rUInt16Item = (const SfxUInt16Item&)pReqArgs->Get( FID_ROW_HEIGHT );
 
                     // #101390#; the value of the macro is in HMM so use HMMToTwips to convert
-                    pTabViewShell->SetMarkedWidthOrHeight( FALSE, SC_SIZE_DIRECT,
-                                    sal::static_int_cast<USHORT>( HMMToTwips(rUInt16Item.GetValue()) ) );
+                    pTabViewShell->SetMarkedWidthOrHeight( false, SC_SIZE_DIRECT,
+                                    sal::static_int_cast<sal_uInt16>( HMMToTwips(rUInt16Item.GetValue()) ) );
                     if( ! rReq.IsAPI() )
                         rReq.Done();
                 }
@@ -531,7 +531,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 {
                     ScViewData* pData      = GetViewData();
                     FieldUnit	eMetric    = SC_MOD()->GetAppOptions().GetAppMetric();
-                    USHORT		nCurHeight = pData->GetDocument()->
+                    sal_uInt16		nCurHeight = pData->GetDocument()->
                                                 GetRowHeight( pData->GetCurY(),
                                                               pData->GetTabNo() );
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
@@ -549,10 +549,10 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     if ( pDlg->Execute() == RET_OK )
                     {
                         long nVal = pDlg->GetInputValue();
-                        pTabViewShell->SetMarkedWidthOrHeight( FALSE, SC_SIZE_DIRECT, (USHORT)nVal );
+                        pTabViewShell->SetMarkedWidthOrHeight( false, SC_SIZE_DIRECT, (sal_uInt16)nVal );
 
                         // #101390#; the value of the macro should be in HMM so use TwipsToEvenHMM to convert
-                        rReq.AppendItem( SfxUInt16Item( FID_ROW_HEIGHT, (USHORT)TwipsToEvenHMM(nVal) ) );
+                        rReq.AppendItem( SfxUInt16Item( FID_ROW_HEIGHT, (sal_uInt16)TwipsToEvenHMM(nVal) ) );
                         rReq.Done();
 
                     }
@@ -568,8 +568,8 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     const SfxUInt16Item&  rUInt16Item = (const SfxUInt16Item&)pReqArgs->Get( FID_ROW_OPT_HEIGHT );
 
                     // #101390#; the value of the macro is in HMM so use HMMToTwips to convert
-                    pTabViewShell->SetMarkedWidthOrHeight( FALSE, SC_SIZE_OPTIMAL,
-                                    sal::static_int_cast<USHORT>( HMMToTwips(rUInt16Item.GetValue()) ) );
+                    pTabViewShell->SetMarkedWidthOrHeight( false, SC_SIZE_OPTIMAL,
+                                    sal::static_int_cast<sal_uInt16>( HMMToTwips(rUInt16Item.GetValue()) ) );
                     ScGlobal::nLastRowHeightExtra = rUInt16Item.GetValue();
 
                     if( ! rReq.IsAPI() )
@@ -594,11 +594,11 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     if ( pDlg->Execute() == RET_OK )
                     {
                         long nVal = pDlg->GetInputValue();
-                        pTabViewShell->SetMarkedWidthOrHeight( FALSE, SC_SIZE_OPTIMAL, (USHORT)nVal );
+                        pTabViewShell->SetMarkedWidthOrHeight( false, SC_SIZE_OPTIMAL, (sal_uInt16)nVal );
                         ScGlobal::nLastRowHeightExtra = nVal;
 
                         // #101390#; the value of the macro should be in HMM so use TwipsToEvenHMM to convert
-                        rReq.AppendItem( SfxUInt16Item( FID_ROW_OPT_HEIGHT, (USHORT)TwipsToEvenHMM(nVal) ) );
+                        rReq.AppendItem( SfxUInt16Item( FID_ROW_OPT_HEIGHT, (sal_uInt16)TwipsToEvenHMM(nVal) ) );
                         rReq.Done();
 
                     }
@@ -614,8 +614,8 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     const SfxUInt16Item&  rUInt16Item = (const SfxUInt16Item&)pReqArgs->Get( FID_COL_WIDTH );
 
                     // #101390#; the value of the macro is in HMM so use HMMToTwips to convert
-                    pTabViewShell->SetMarkedWidthOrHeight( TRUE, SC_SIZE_DIRECT,
-                                    sal::static_int_cast<USHORT>( HMMToTwips(rUInt16Item.GetValue()) ) );
+                    pTabViewShell->SetMarkedWidthOrHeight( sal_True, SC_SIZE_DIRECT,
+                                    sal::static_int_cast<sal_uInt16>( HMMToTwips(rUInt16Item.GetValue()) ) );
                     if( ! rReq.IsAPI() )
                         rReq.Done();
                 }
@@ -623,7 +623,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 {
                     FieldUnit   eMetric	   = SC_MOD()->GetAppOptions().GetAppMetric();
                     ScViewData* pData      = GetViewData();
-                    USHORT		nCurHeight = pData->GetDocument()->
+                    sal_uInt16		nCurHeight = pData->GetDocument()->
                                                 GetColWidth( pData->GetCurX(),
                                                              pData->GetTabNo() );
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
@@ -641,10 +641,10 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     if ( pDlg->Execute() == RET_OK )
                     {
                         long nVal = pDlg->GetInputValue();
-                        pTabViewShell->SetMarkedWidthOrHeight( TRUE, SC_SIZE_DIRECT, (USHORT)nVal );
+                        pTabViewShell->SetMarkedWidthOrHeight( sal_True, SC_SIZE_DIRECT, (sal_uInt16)nVal );
 
                         // #101390#; the value of the macro should be in HMM so use TwipsToEvenHMM to convert
-                        rReq.AppendItem( SfxUInt16Item( FID_COL_WIDTH, (USHORT)TwipsToEvenHMM(nVal)) );
+                        rReq.AppendItem( SfxUInt16Item( FID_COL_WIDTH, (sal_uInt16)TwipsToEvenHMM(nVal)) );
                         rReq.Done();
 
                     }
@@ -660,8 +660,8 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     const SfxUInt16Item&  rUInt16Item = (const SfxUInt16Item&)pReqArgs->Get( FID_COL_OPT_WIDTH );
 
                     // #101390#; the value of the macro is in HMM so use HMMToTwips to convert
-                    pTabViewShell->SetMarkedWidthOrHeight( TRUE, SC_SIZE_OPTIMAL,
-                                    sal::static_int_cast<USHORT>( HMMToTwips(rUInt16Item.GetValue()) ) );
+                    pTabViewShell->SetMarkedWidthOrHeight( sal_True, SC_SIZE_OPTIMAL,
+                                    sal::static_int_cast<sal_uInt16>( HMMToTwips(rUInt16Item.GetValue()) ) );
                     ScGlobal::nLastColWidthExtra = rUInt16Item.GetValue();
 
                     if( ! rReq.IsAPI() )
@@ -685,11 +685,11 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     if ( pDlg->Execute() == RET_OK )
                     {
                         long nVal = pDlg->GetInputValue();
-                        pTabViewShell->SetMarkedWidthOrHeight( TRUE, SC_SIZE_OPTIMAL, (USHORT)nVal );
+                        pTabViewShell->SetMarkedWidthOrHeight( sal_True, SC_SIZE_OPTIMAL, (sal_uInt16)nVal );
                         ScGlobal::nLastColWidthExtra = nVal;
 
                         // #101390#; the value of the macro should be in HMM so use TwipsToEvenHMM to convert
-                        rReq.AppendItem( SfxUInt16Item( FID_COL_OPT_WIDTH, (USHORT)TwipsToEvenHMM(nVal) ) );
+                        rReq.AppendItem( SfxUInt16Item( FID_COL_OPT_WIDTH, (sal_uInt16)TwipsToEvenHMM(nVal) ) );
                         rReq.Done();
                     }
                     delete pDlg;
@@ -698,24 +698,24 @@ void ScCellShell::Execute( SfxRequest& rReq )
             break;
 
         case FID_COL_OPT_DIRECT:
-            pTabViewShell->SetMarkedWidthOrHeight( TRUE, SC_SIZE_OPTIMAL, STD_EXTRA_WIDTH );
+            pTabViewShell->SetMarkedWidthOrHeight( sal_True, SC_SIZE_OPTIMAL, STD_EXTRA_WIDTH );
             rReq.Done();
             break;
 
         case FID_ROW_HIDE:
-            pTabViewShell->SetMarkedWidthOrHeight( FALSE, SC_SIZE_DIRECT, 0 );
+            pTabViewShell->SetMarkedWidthOrHeight( false, SC_SIZE_DIRECT, 0 );
             rReq.Done();
             break;
         case FID_ROW_SHOW:
-            pTabViewShell->SetMarkedWidthOrHeight( FALSE, SC_SIZE_SHOW, 0 );
+            pTabViewShell->SetMarkedWidthOrHeight( false, SC_SIZE_SHOW, 0 );
             rReq.Done();
             break;
         case FID_COL_HIDE:
-            pTabViewShell->SetMarkedWidthOrHeight( TRUE, SC_SIZE_DIRECT, 0 );
+            pTabViewShell->SetMarkedWidthOrHeight( sal_True, SC_SIZE_DIRECT, 0 );
             rReq.Done();
             break;
         case FID_COL_SHOW:
-            pTabViewShell->SetMarkedWidthOrHeight( TRUE, SC_SIZE_SHOW, 0 );
+            pTabViewShell->SetMarkedWidthOrHeight( sal_True, SC_SIZE_SHOW, 0 );
             rReq.Done();
             break;
 
@@ -737,7 +737,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
             {
                 // test whether to merge or to split
                 bool bMerge = false;
-                BOOL bCenter = FALSE;
+                sal_Bool bCenter = false;
                 switch( nSlot )
                 {
                     case FID_MERGE_ON:
@@ -748,7 +748,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     break;
                     case FID_MERGE_TOGGLE:
                     {
-                        bCenter = TRUE;
+                        bCenter = true;
                         SfxPoolItem* pItem = 0;
                         if( rBindings.QueryState( nSlot, pItem ) >= SFX_ITEM_DEFAULT )
                             bMerge = !static_cast< SfxBoolItem* >( pItem )->GetValue();
@@ -759,17 +759,17 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 if( bMerge )
                 {
                     // merge - check if to move contents of covered cells
-                    BOOL bMoveContents = FALSE;
-                    BOOL bApi = rReq.IsAPI();
+                    sal_Bool bMoveContents = false;
+                    sal_Bool bApi = rReq.IsAPI();
                     const SfxPoolItem* pItem;
                     if ( pReqArgs &&
-                        pReqArgs->GetItemState(nSlot, TRUE, &pItem) == SFX_ITEM_SET )
+                        pReqArgs->GetItemState(nSlot, sal_True, &pItem) == SFX_ITEM_SET )
                     {
                         DBG_ASSERT(pItem && pItem->ISA(SfxBoolItem), "falsches Item");
                         bMoveContents = ((const SfxBoolItem*)pItem)->GetValue();
                     }
 
-                    if (pTabViewShell->MergeCells( bApi, bMoveContents, TRUE, bCenter ))
+                    if (pTabViewShell->MergeCells( bApi, bMoveContents, true, bCenter ))
                     {
                         if (!bApi && bMoveContents)             // "ja" im Dialog geklickt
                             rReq.AppendItem( SfxBoolItem( nSlot, bMoveContents ) );
@@ -803,7 +803,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
                 const ScMarkData& rMark = GetViewData()->GetMarkData();
                 if ( !rMark.IsMarked() && !rMark.IsMultiMarked() )
-                    pTabViewShell->MarkDataArea( TRUE );
+                    pTabViewShell->MarkDataArea( sal_True );
 
                 GetViewData()->GetSimpleArea( nStartCol,nStartRow,nStartTab,
                                               nEndCol,nEndRow,nEndTab );
@@ -815,7 +815,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                     {
                         const SfxStringItem& rNameItem = (const SfxStringItem&)pReqArgs->Get( SID_AUTOFORMAT );
                         ScAutoFormat* pFormat = ScGlobal::GetAutoFormat();
-                        USHORT nIndex = pFormat->FindIndexPerName( rNameItem.GetValue() );
+                        sal_uInt16 nIndex = pFormat->FindIndexPerName( rNameItem.GetValue() );
 
                         pTabViewShell->AutoFormat( nIndex );
 
@@ -871,16 +871,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
                 {
                     // TODO/LATER: when is this code executed?
                     pTabViewShell->Escape();
-                    //SfxObjectShell* pObjSh = GetViewData()->GetSfxDocShell();
-                    //if (pObjSh->GetInPlaceObject() &&
-                    //    pObjSh->GetInPlaceObject()->GetIPClient())
-                    //{
-                    //    GetViewData()->GetDocShell()->
-                    //        DoInPlaceActivate(FALSE);       // OLE beenden
-                    //}
                 }
-
-//				SetSumAssignMode(); //ScInputWindow
             }
             break;
 
@@ -890,7 +881,7 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
         case SID_DETECTIVE_FILLMODE:
             {
-                BOOL bOldMode = pTabViewShell->IsAuditShell();
+                sal_Bool bOldMode = pTabViewShell->IsAuditShell();
                 pTabViewShell->SetAuditShell( !bOldMode );
                 pTabViewShell->Invalidate( nSlot );
             }
@@ -898,18 +889,18 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
         case SID_OPENDLG_CONDFRMT:
             {
-                USHORT			nId  = ScCondFormatDlgWrapper::GetChildWindowId();
+                sal_uInt16			nId  = ScCondFormatDlgWrapper::GetChildWindowId();
                 SfxViewFrame* pViewFrm = pTabViewShell->GetViewFrame();
                 SfxChildWindow* pWnd = pViewFrm->GetChildWindow( nId );
 
-                pScMod->SetRefDialog( nId, pWnd ? FALSE : TRUE );
+                pScMod->SetRefDialog( nId, pWnd ? false : sal_True );
             }
             break;
 
         //	----------------------------------------------------------------
 
         case FID_INPUTLINE_STATUS:
-            DBG_ERROR("Execute von InputLine-Status");
+            OSL_FAIL("Execute von InputLine-Status");
             break;
 
         case SID_STATUS_DOCPOS:
@@ -920,11 +911,11 @@ void ScCellShell::Execute( SfxRequest& rReq )
 
         case SID_MARKAREA:
             // called from Basic at the hidden view to select a range in the visible view
-            DBG_ERROR("old slot SID_MARKAREA");
+            OSL_FAIL("old slot SID_MARKAREA");
             break;
 
         default:
-            DBG_ERROR("Unbekannter Slot bei ScCellShell::Execute");
+            OSL_FAIL("Unbekannter Slot bei ScCellShell::Execute");
             break;
     }
 }
